-- 'Legacy' class to manipulate legacies and full list of all legacies for each class

-- Type of a legacy
Type = { 
	None = 0, 
	Minor = 1, 
	Major = 2, 
	Stat = 3,
	-- default legacies below
	DPS = 4, 
	TacticalDamageRating = 5, 
	TacticalHealingRating = 6, 
	IncomingHealingRating = 7, 
	ShieldUse = 8 
};

-- Modifier type of a legacy, mostly for conveniance in entering data as numeric values rather than strings
Modifier = { 
	None = 0, 
	Number = 1, 
	Percent = 2, 
	Cooldown = 3, 
	Resist = 4, 
	Mitigation = 5, 
	Rating = 6, 
	DPS = 7, 
	Duration = 8, 
	Range = 9
};

--specifies how certain legacies need to be adjusted for age & level
Adjust = { 
	None = 0, 
	LevelAge = 1, -- every level above 51 and age above third grants a "free" rank
	LevelRangeAge = 2, -- every age above third and certain levels grant a "free" rank
	LevelPerAge = 3, -- every level above 51 grants a "free rank", separate tables per age
	IncomingHealingRating = 4, -- different tables for ranges lvl 51-60 & 61-65, as well as for different ages
	-- special case for Sting Damage legacy. Shifts ranks as for Adjust.LevelRangeAge but also gets fewer ranks in the process after the first shift (likely broken Turbine side, but we mimic that)
	StingDamage = 5, 
	LevelRange2Age = 6, -- same as LevelRangeAge but different level range table
};

-- how many "free" ranks a legacy get at certain levels, if adjust = LevelRangeAge
LevelRangeBonus = { 
	[51]=0,
	[52]=0,
	[53]=0,
	[54]=1,
	[55]=1,
	[56]=1,
	[57]=1,
	[58]=2,
	[59]=2,
	[60]=2,
	[61]=2,
	[62]=2,
	[63]=2,
	[64]=2,
	[65]=3 
};

-- seems to apply to "ranged" legacies
-- TODO: check values
LevelRange2Bonus = { 
	[51]=0, -- checked
	[52]=0,
	[53]=0,
	[54]=1,
	[55]=1,
	[56]=1, -- checked
	[57]=1,
	[58]=1,
	[59]=1, -- checked
	[60]=1, -- checked
	[61]=1,
	[62]=1,
	[63]=1,
	[64]=1,
	[65]=2  -- checked
};


-- Legacy class
-- TODO: callbacks may be called when values remain identical despite level/age modification, would be better not to
Legacy = class( Turbine.Object )
function Legacy:Constructor( data, item )
	Turbine.Object.Constructor( self );
	
	self.legendaryItem = item;
	self.level = item:GetLevelToUse();
	self.age = item:GetAge();
	
	self.name = data.name;
	self.type = data.type;
	self.modifierType = data.modType;
	self.modifiers = data.mod;
	self.costs = data.cost;
	self.adjust = data.adjust;
	self.adjustCost = data.adjustCost;

	self.tier = 1; -- default to tier 1
	self.rank = 1; -- default to rank 1
	
	-- items hold a list of all possible legacies, 'active' ones represent the user's choice
	self.active = false; 
	
	-- Events. No parameters
	self.Changed = Equendil.Utils.Event(); -- fired off for any change in the legacy
	self.CostChanged = Equendil.Utils.Event(); -- fired off when the 'cost' of a legacy has changed

	-- DEBUG
	if self.adjust == Adjust.LevelRangeAge and #self.modifiers ~= 14 then
		Turbine.Log:Information( "Rotten legacy: " .. self.name );
	end
	
	if self.adjust == nil and #self.modifiers - 1 ~= #self.costs[1] then
		Turbine.Log:Information( "Rotten legacy: " .. self.name );
	end
	
	-- callback to monitor level/age changes on a LI for "adjustable" legacies
	local callback = function() 
		if self.adjust == nil or self.adjust == Adjust.None then
			return; -- if the legacy does not need adjustment for level/age, do nothing
		end

		-- if either level or age changed, save the new values and notify the legacy has changed. 
		-- Test is *necessary* to avoid an infinite callback loop (legacy->item->legacy->item->legacy...)
		if self.legendaryItem:GetLevelToUse() ~= self.level or self.legendaryItem:GetAge() ~= self.age then
			-- 'Sting Damage' gets fewer ranks starting with +2 shift, likely a bug on Turbine side of things, but we mimic that anyway
			if self.adjust == Adjust.StingDamage then 
				if self.rank > self:GetMaxRank() then
					self.rank = self:GetMaxRank(); -- adjust rank for sting if > max rank
				end
			end
			
			self.level = self.legendaryItem:GetLevelToUse();
			self.age = self.legendaryItem:GetAge();
			
			self.Changed();
		end
	end
	self.legendaryItem.Changed:Add( callback );
end

-- Straight forward accessors & methods
function Legacy:GetName() return self.name end
function Legacy:GetType() return self.type end
function Legacy:GetRank() return self.rank end
function Legacy:GetTier() return self.tier end
function Legacy:GetMaxTier() return #self.costs end
function Legacy:GetModifierOf( rank ) return self.modifiers[rank] end
function Legacy:GetCurrentModifier() return self.modifiers[self.rank] end
function Legacy:GetModifierStringOf(rank) return self:GetModifierValueStringOf(rank) .. self.name; end
function Legacy:GetCurrentModifierValueString()	return self:GetModifierValueStringOf( self.rank ); end
function Legacy:GetCurrentModifierString() return self:GetModifierStringOf( self.rank ) end
function Legacy:GetTotalCurrentCost() return self:GetTotalCostOf( self.tier, self.rank ); end
function Legacy:IsActive() return self.active end
function Legacy:SetActive( status ) self.active = status; self.Changed(); end

-- returns how many ranks a legacy has
function Legacy:GetMaxRank() 
	-- sting gets fewer ranks starting with +2 shift
	if self.adjust == Adjust.StingDamage then 
		local shift = LevelRangeBonus[self.legendaryItem:GetLevelToUse()] + ( 3 - self.legendaryItem:GetAge() );
		if shift > 1 then
			return #self.costs[1] + 2 - shift;
		end
	end
	
	return #self.costs[1] + 1; -- one less entry in cost tables than ranks (first rank is free) 
end 

--- returns the cost of a given rank of the legacy set to tier <tier>
function Legacy:GetCostOf( tier, rank )	
	if rank == 1 then return 0 end; -- rank 1 is always free
	
	-- some legacies have variable costs at rank 2
	if rank == 2 and self.adjustCost ~= nil then
		local costIndex = 1 + LevelRangeBonus[self.legendaryItem:GetLevelToUse()] + ( 3 - self.legendaryItem:GetAge() );
		return self.adjustCost[tier][costIndex];
	end
	
	-- any other case, return table value
	return self.costs[tier][rank - 1] -- one less entry in cost tables than there are ranks (first rank is free)
end 

-- set the rank of a legacy
-- not testing bounds
function Legacy:SetRank( rank ) 
	if self.rank ~= rank then
		self.rank = rank;
		self.Changed();
		self.CostChanged();
	end
end

-- set the tier of a legacy
-- not testing bounds
function Legacy:SetTier( tier ) 
	if self.tier ~= tier then
		self.tier = tier;
		self.Changed();
		self.CostChanged();
	end
end

-- Get the total cost of a legacy of tier <tier> at rank <rank>
function Legacy:GetTotalCostOf( tier, rank )
	local total = 0;
	for i = 2, rank do
		total = total + self:GetCostOf( tier, i );
	end
	return total;
end

-- Returns whether a legacy is the default legacy for a legendary item (DPS, Tactical Damage Rating etc)
function Legacy:IsDefault()	
	return not ( self.type == Type.Minor or self.type == Type.Major or self.type == Type.Stat ); 
end

local ModFormat = {
	[Modifier.Number] = "%+g ",
	[Modifier.Percent] = "%+g%% ",
	[Modifier.Cooldown] = "%+g ",
	[Modifier.Resist] = "%+d ",
	[Modifier.Mitigation] = "%+d ",
	[Modifier.Rating] = "%+g ",
	[Modifier.DPS] = "%g ",
	[Modifier.Duration] = "+%g ",
	[Modifier.Range] = "%+g "
}

-- Returns the description of the legacy for a given rank
function Legacy:GetModifierValueStringOf(rank)
	local modIndex = rank; -- index in the modifier tables
	local modifier = nil;
	
	-- adjust index if needed and retrieve modifier value
	if self.adjust == Adjust.LevelAge then
		-- shift by one for every level above 51 and every age above third age
		modIndex = modIndex + (3 - self.legendaryItem:GetAge() ) + ( self.legendaryItem:GetLevelToUse() - 51 ) ;
		modifier = self.modifiers[modIndex];
	elseif self.adjust == Adjust.LevelRangeAge or self.adjust == Adjust.StingDamage then
		-- shift by one for every age above third age, and for certain level ranges specified elsewhere
		-- NOTE: sting damage is probably bugged, shifts as if it was Adjust.LevelRangeAge *but* gets fewer ranks (handled elsewhere)  starting with the 2nd shift
		modIndex = modIndex + LevelRangeBonus[self.legendaryItem:GetLevelToUse()] + ( 3 - self.legendaryItem:GetAge() );
		modifier = self.modifiers[modIndex];
	elseif self.adjust == Adjust.LevelRange2Age then
		-- same as above, different level range bonus
		modIndex = modIndex + LevelRange2Bonus[self.legendaryItem:GetLevelToUse()] + ( 3 - self.legendaryItem:GetAge() );
		modifier = self.modifiers[modIndex];
	elseif self.adjust == Adjust.LevelPerAge then
		-- shift by one for every level above 51, different tables per age
		modIndex = modIndex + self.legendaryItem:GetLevelToUse() - 51;
		modifier = self.modifiers[self.legendaryItem:GetAge()][modIndex];
	elseif self.adjust == Adjust.IncomingHealingRating then
		-- different tables for 1st, 2nd, third age & for lvl 51-60 & 61-65 ranges
		if self.legendaryItem:GetLevelToUse() <= 60 then
			modifier = self.modifiers[1][self.legendaryItem:GetAge()][modIndex]; -- lvl 51-60 table
		else
			modifier = self.modifiers[2][self.legendaryItem:GetAge()][modIndex]; -- lvl 61+ table
		end
	else
		modifier = self.modifiers[modIndex];
	end
	
	-- cooldown reducations are entered as positive values for convenience, so reversing that here
	if self.modifierType == Modifier.Cooldown then
		modifier = -modifier;
	end
		
	return string.format( ModFormat[self.modifierType], modifier );
end

		
-- Tables of  legacy costs / rank that most legacies use at various tiers. Tables are numbered by their rank 9 cost for 'easy' identification
Cost252 = 	{32,48,69,95,126,163,205,252};
Cost216 =	{27,41,59,81,108,140,176,216};
Cost180 =	{23,34,49,68,90,117,147,180};
Cost144 =	{18,27,39,54,72,93,117,144};
Cost126 = 	{16,24,35,48,63,82,103,126};
Cost108 = 	{14,21,30,41,54,70,88,108};
Cost90 =	{12,17,25,34,45,59,74,90};
Cost72 = 	{9,14,20,27,36,47,59,72};
Cost63 =	{8,12,18,24,32,41,52,63};
Cost59 =	{8,11,16,22,30,36,48,59}; -- TODO triple check  36
Cost54 =	{7,11,15,21,27,35,44,54};
Cost50 = 	{7,10,14,19,25,32,41,50};
Cost45 =	{6,9,13,17,23,30,37,45};
Cost41 = 	{6,8,11,16,21,27,33,41};
Cost36 =	{5,7,10,14,18,24,30,36};
Cost32 =	{4,6,9,12,16,21,26,32};
Cost27 =	{4,6,8,11,14,18,22,27};
Cost23 =	{3,5,7,9,12,15,19,23};
Cost18 =	{3,4,5,7,9,12,15,18};

-- Tables of legacy costs per rank per tier, that are used for most legacies. Tables are numbered by their tier6/rank9 cost for 'easy" identification
CostTable72 = { Cost252, Cost216, Cost180, Cost144, Cost108, Cost72}; -- 36*(8-t)  ?
CostTable63 = { Cost216, Cost180, Cost144, Cost108, Cost72, Cost63 };
CostTable54 = { Cost180, Cost144, Cost108, Cost72, Cost63, Cost54 }; -- 214

CostTable36 = { Cost126, Cost108, Cost90, Cost72, Cost54, Cost36 }; -- total at rank 9 = 144 points tor tier 6
CostTable32 = { Cost108, Cost90, Cost72, Cost54, Cost36, Cost32 }; -- total at rank 9 = 126 points tor tier 6
CostTable27 = { Cost90, Cost72, Cost54, Cost36, Cost32, Cost27 }; -- total at rank 9 = 110 points for tier 6

CostTable23 = { Cost72, Cost59, Cost50, Cost41, Cost32, Cost23 }; --total at rank 9 = 93 points for tier 6

CostTable18 = { Cost63, Cost54, Cost45, Cost36, Cost27, Cost18 }; -- total at rank 9 = 73 points for tier 6

-- Costs of a default legacy per rank. Default legacies don't have tiers, so only one inner table.
CostTableDefault = { {14, 21, 30, 41, 54, 70 } };


-- ADJUSTMENT FOR RANK2 COSTS
-- 'CostAdjust' tables are numbered by their max rank cost for identification
-- 'CostTableAdjust' tables are numbered by their tier 1, max rank cost for identification
-- NOTE: 
--	- Many values are extrapolated due to the number of possible combinations (18 legacies * 6 tiers * 6 ranges) 
--	and lack of data (generally lacking on: lower levels and lvl 65 first age, minor legacies, and the less common tiers 1,5,6)
-- 	- Should be generally correct, but some values may be off by one or more rarely two points, barring other mistakes
--	- Keeping track of verified values and extrapolation methods somewhere else

CostAdjust378 = {111,95,79,63,48,32}; 
CostAdjust324 = {95,81,68,54,41,27};
CostAdjust270 = {79,68,57,45,34,23};
CostAdjust216 = {63,54,45,36,27,18};
CostAdjust162 = {48,41,34,27,21,14};
CostAdjust108_1 = {32,27,23,18,14,9};
CostAdjust95 = {28,24,20,16,12,8};
CostAdjust81 = {24,21,17,14,11,7};

-- Call of the Second Age Targets (MNS), Ancient Craft Targets (LRM), Bane Flare Target (LRM), Fire-lore Targets (LRM), Guardian Area Effect Melee Targets (GRD)
CostTableAdjust378 = { CostAdjust378, CostAdjust324, CostAdjust270, CostAdjust216, CostAdjust162, CostAdjust108_1 };
-- Pressing Attack Max Targets (CPT)
CostTableAdjust324 = { CostAdjust324, CostAdjust270, CostAdjust216, CostAdjust162, CostAdjust108_1, CostAdjust95 };
-- Challenge Targets (GRD), Vivid Imagery Targets (RNK), Maximum Targets for AoE Skills (HNT)
CostTableAdjust270 = { CostAdjust270, CostAdjust216, CostAdjust162, CostAdjust108_1, CostAdjust95, CostAdjust81 };

CostAdjust331 = {94,79,63,48,31,28};
CostAdjust284 = {81,68,54,41,27,24};
CostAdjust237 = {68,57,45,34,23,20};
CostAdjust189 = {54,45,36,27,18,16};
CostAdjust142 = {41,34,27,21,14,12};
CostAdjust119 = {34,28,23,17,12,10};
CostAdjust95 = {27,23,18,14,9,8};
CostAdjust71 = {21,17,14,11,7,6};
CostAdjust48 = {12,11,9,7,6,4};

-- Rend pulses (CHP), Guardian Bleed Pulses (GRD)
CostTableAdjust331 = { CostAdjust331, CostAdjust284, CostAdjust237, CostAdjust189, CostAdjust142, CostAdjust95 };
-- Pulse Modifier for Glee (BRG)
CostTableAdjust189 = { CostAdjust189, CostAdjust142, CostAdjust119, CostAdjust95, CostAdjust71, CostAdjust48 };

-- Burning Embers Pulses (LRM), Wizard Fire Pulses (LRM)
CostTableAdjust166 = {
	{48,40,32,24,16,14}, -- 166
	{41,34,27,21,14,12}, --142
	{34,29,23,17,12,9}, --118
	{27,23,18,14,9,8}, --95
	{21,17,14,11,7,6}, --71
	{14,12,9,7,5,4} -- 48
};

-- Stealth Level (BRG), StealthDetection (HNT)
CostTableAdjustStealth = {
	{158,142,126,111,95,80}, -- 142  
	{134,121,108,95,81,69}, -- 122
	{112,101,90,79,68,57}, -- 102
	{90,81,72,63,54,45}, -- 81
	{67,61,54,48,41,35}, -- 61
	{46,41,36,32,27,23} -- 41
};		

-- Ardour/Glory Pip Interval (CHP)
-- NOTE: unreliable
CostTableAdjust376 = {
	{111,95,79,63,48,32}, -- 376
	{95,81,68,54,41,27}, -- 322
	{79,68,57,45,34,23}, -- 269
	{63,54,45,36,27,18}, -- 215
	{48,41,34,27,21,14}, -- 161
	{32,27,23,18,14,9}, -- 108
};

-- Increased Ranged for Harmstring (CHP)
-- Not sure that one has variable costs actually, got very little data, TODO
CostTableAdjustHarmstringRange = {
	{34,34,34,34,34,34}, -- 142
	{27,27,27,27,27,27}, -- 122
	{23,23,23,23,23,23}, -- 102
	{18,18,18,18,18,18}, -- 81
	{14,14,14,14,14,14}, -- 61
	{9,9,9,9,9,9} -- 41
};

-- Creates a table of 14 values for Adjust.LevelRangeAge, starting from <base>, each succsessive value is increased by <increment>
ModifierTableRating = function( base, increment ) 
	local tab = {};
	for i = 1, 14 do
		tab[i] = base + ( ( i - 1 ) * increment );
	end
	
	return tab;
end

-- MODIFIER VALUES OF DEFAULT LEGACIES
--NOTE: Tactical classes have their melee dps set as if rank 4

ModifierTableDefaultRating = { 0.5,0.8,0.9,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20 }; -- Tactical Damage Rating, Tactical Healing Rating, Shield Use

ModifierTableDPS1H = { -- DPS tables for one handed weapons
	{0,0,0,0,0,0,0,0,50.8,52.8,54.8,56.9,58.4,60.0,61.5,63.0,64.5,67.8,71.1,74.7,78.5}, -- first age lvl 51 rank 1 -> level 65 rank 7
	{0,0,38.5,39.4,40.6,41.7,43.8,46.0,48.3,50.1,52.1,54.1,55.5,57.0,58.4,59.9,61.3,64.4,67.6,71.0,74.6}, -- second age, lvl 51 rank 1 -> lvl 65 rank 7
	{35.7,36.4,37.1,38.0,39.0,40.1,42.1,44.2,46.5,48.3,50.1,52.0,53.4,54.8,56.2,57.6,59.0,62.0,65.1,68.3,71.8 }, -- third age, lvl 51 rank 1 -> lvl 65 rank 7
};

ModifierTableDPS2H = { -- DPS tables for bows, crossbows, javelins & any two handed weapon
	{0,0,0,0,0,0,0,0,57.6,59.8,62.1,64.5,66.2,68.0,69.7,71.4,73.1,76.8,80.7,84.7,88.9}, -- first age lvl 51 rank 1 -> level 65 rank 7
	{0,0,0,44.7,46.0,47.3,49.6,52.1,54.7,56.8,59.0,61.3,62.9,64.6,66.2,67.9,69.5,73.0,76.7,80.5,84.5}, -- second age, lvl 51 rank 1 -> lvl 65 rank 7
	{40.7,41.4,42.2,43.0,44.2,45.5,47.8,50.1,52.7,54.7,56.8,59.0,60.6,62.1,63.7,65.3,66.9,70.3,73.8,77.5,81.3 }, -- third age lvl 51 rank 1 -> lvl 65 rank 7
}

ModifierTableIncomingHealingRating = { --incoming healing rating modifiers
	{ -- lvl 51-60: 1st, 2nd, 3rd age
		{720,920,1120,1320,1520,1720,1920}, -- lvl 59 1st age
		{480,680,880,1080,1280,1480,1680}, -- lvl 51-60 2nd age -- TODO CHECK (checked 58)
		{240,440,640,840,1040,1240,1440}, -- lvl 51 - 60 third age TODO CHECK (checked 51,54,56,57,59,60)
	}, { -- lvl 61-65: 1st, 2nd, 3rd age
		{780,996,1213,1430,1646,1863,2080}, -- extrapolated values, TODO check
		{520,736,953,1170,1386,1603,1820}, -- lvl 65 2nd age
		{260,476,693,910,1126,1343,1560}, -- third age checked 61 - 65	
	}
}
					
-- COMPLETE LISTING OF LEGACIES FOR EACH CLASS BELOW

LegaciesMinstrel = 
{
	{
		name = "Weapon",
		defaultLegacy = {
			name = "Tactical Damage Rating",
			type = Type.TacticalDamageRating,
			modType = Modifier.Rating,
			mod = ModifierTableDefaultRating,
			adjust = Adjust.LevelAge, -- adjust for level/age
			cost = CostTableDefault,
		},
		legacies = {
			{
				name = "Call of Orome Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {2,4.2, 6.5, 8.7, 11, 13.2, 15.5, 17.7, 20 },
				cost = CostTable36
			}, {
				name = "Cure Fear Cooldown",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {1,4,8,11,15,19,22,26,30},
				cost = CostTable18
			},{
				name = "Call of the Second Age Targets",
				type = Type.Minor,
				modType = Modifier.Number,
				mod = {1,2,3,4,5},
				cost = {
					{0,166,308,378}, 
					{0,142,264,324}, 
					{0,119,220,270},
					{0,95,176,216},
					{0,71,132,162},
					{0,48,88,108}
				}, 
				adjustCost = CostTableAdjust378
			},{
				name = "Call to Fate Critical Multiplier",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,2.7,4.5,6.2,8,9.7,11.5,13.2,15},
				cost = CostTable36
			},{
				name = "Still as Death Cooldown",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {10, 83,157,231,305,348,452,526,600},
				cost = CostTable27
			},{
				name = "Soliloquy of Spirit Pulses",
				type = Type.Major,
				modType = Modifier.Number,
				mod = ModifierTableRating(1,1),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable27
			}, {
				name = "Rally Cooldown",
				type = Type.Major,
				modType = Modifier.Cooldown,
				mod = {10,83,157,231,305,378,452,526,600},
				cost = CostTable27
			}, {
				name = "Tier 1 Ballad Damage",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {2,5.5,9,12.5,16,19.5,23,26.5,30},
				cost = CostTable27
			}, {
				name = "Tier 2 Ballad Damage",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {2,5.5,9,12.5,16,19.5,23,26.5,30},
				cost = CostTable27
			}, {
				name = "Piercing Cry Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {2,5.5,9,12.5,16,19.5,23,26.5,30},
				cost = CostTable27
			}, {
				name = "Target Resist Rating (Call to War)",
				type = Type.Major,
				modType = Modifier.Resist,
				mod = ModifierTableRating(-460,-50),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable27
			}, {
				name = "Triumphant Spirit Cooldown",
				type = Type.Major,
				modType = Modifier.Cooldown,
				mod = {10,46.3,82.5,118.8,155,191.3,227.5,263.5,300},
				cost = CostTable18
			}, {
				name = "Target Resist Rating (Cry of the Valar)",
				type = Type.Minor,
				modType = Modifier.Resist,
				mod = ModifierTableRating(-460,-50),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable27
			}, {
				name = "War-speech Tail Effect Duration",
				type = Type.Major,
				modType = Modifier.Cooldown,
				mod = {1,1.5,2,2.5,3,3.5,4,4.5,5},
				cost = CostTable36
			}, {
				name = "Threat from Healing",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {-1,-2,-3,-4,-6,-7,-8,-9,-10},
				cost = CostTable36
			}
		}
	},
	{
		name = "Song book",
		defaultLegacy = {
			name = "Tactical Healing Rating",
			type = Type.TacticalHealingRating,
			modType = Modifier.Rating,
			mod = ModifierTableDefaultRating,
			cost = CostTableDefault,
			adjust = Adjust.LevelAge
		},
		legacies = 
		{
			{
				name = "Ballad of Composure (Ranged Damage)",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,1.5,2,2.5,3,3.5,4,4.5,5},
				cost = CostTable23
			}, {
				name = "Ballad of Composure  (Fear Resistance)",
				type = Type.Minor,
				modType = Modifier.Resist,
				mod = ModifierTableRating(207,19),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable27
			}, {
				name = "Ballad of Flame (Fire Defence",
				type = Type.Minor,
				modType = Modifier.Mitigation,
				mod = ModifierTableRating(207,19),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable27
			}, {
				name = "Ballad of War (Melee Damage)",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {2,3,4,5,6,7,8,9,10},
				cost = CostTable27
			}, {
				name = "Ballad of Flame (Tactical Damage)",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,1.5,2,2.5,3,3.5,4,4.5,5},
				cost = CostTable27
			}, {
				name = "Cry of the Chorus Cooldown",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {10,46,82,118,155,191,227,263,300},
				cost = CostTable32
			}, {
				name = "Chord of Salvation Cooldown",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {1,2,3,4,5,6,7,8,10},
				cost = CostTable32
			}, {
				name = "Healing & Motivation Skills Healing",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2,3,4,6,7,8,9,10},
				cost = CostTable32
			}, {
				name = "Bolster Courage Healing",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2,3,4,6,7,8,9,10},
				cost = CostTable36
			}, {
				name = "Echoes of Battle Resistance Debuff",
				type = Type.Minor,
				modType = Modifier.Resist,
				mod = ModifierTableRating(-207,-19),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable27
			}, {
				name = "Healing Skills Power Cost",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {-1,-2,-3,-4,-6,-7,-8,-9,-10 },
				cost = CostTable36
			}, {
				name = "Raise the Spirit Healing",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2,3,4,6,7,8,9,10},
				cost = CostTable36
			}, {
				name = "Song of the Dead Cooldown",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {1,4,8,11,15,19,22,26,30 },
				cost = CostTable23
			}, {
				name = "Target Resist Rating (Songs)",
				type = Type.Minor,
				modType = Modifier.Resist,
				mod = ModifierTableRating(-207,-19),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable27
			}, {
				name = "Target Resist Rating (Ballads)",
				type = Type.Major,
				modType = Modifier.Resist,
				mod = ModifierTableRating(-460,-50),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable32
			}, {
				name = "Inspire Fellows Healing",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2,3,4,6,7,8,9,10},
				cost = CostTable36
			}
		}
	}
}

LegaciesBurglar = 
{
	{
		name = "Weapon",
		defaultLegacy = {
			name = "DPS",
			type = Type.DPS,
			modType = Modifier.Rating,
			mod = ModifierTableDPS1H,
			cost = CostTableDefault,
			adjust = Adjust.LevelPerAge,
		}, 
		legacies = 
		{
			{
				name = "Critical Response Skill Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.1,3.2,4.3,5.5,6.6,7.7,8.8,10},
				cost = CostTable36
			}, {
				name = "Feint Attack Cooldown",
				type = Type.Major,
				modType = Modifier.Cooldown,
				mod = {1, 6,12,17,23,28,34,39,45},
				cost = CostTable27
			}, {
				name = "Cunning Attack Bleed Stack Chance",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {3,11,19,27,34,42,50,58,66},
				cost = CostTable32
			}, {
				name = "Burglar Skill Bleed Damage Multiplier",
				type = Type.Major, 
				modType = Modifier.Percent,
				mod = {1,2.7,4.5,6.2,8,9.7,11.5,13.2,15},
				cost = CostTable36
			}, {
				name = "Location is Everything Cooldown",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {5,15,26,36,47,58,68,79,90},
				cost = CostTable18
			}, {
				name = "Lucky Strike Cooldown",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {1,6,12,17,23,28,34,39,45},
				cost = CostTable27
			}, {
				name = "Provoke Threat Up Rating",
				type = Type.Minor,
				modType = Modifier.Rating,
				mod = ModifierTableRating(1,1),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable23
			}, {
				name = "Riddle Range",
				type = Type.Minor,
				modType = Modifier.Number,
				-- TODO CHECK VALUES 4+ checked on lvl 65 2nd age, +3 on level 59 2nd age, +2 lvl 57 3rd age, +1 starter weeapon = 
				-- {1,0,2,3,4 ...
				mod = {1,2,3,4,5,6,7,8,9,10,11,12,13}, 
				adjust = Adjust.LevelRange2Age, -- TODO CHECK
				cost = CostTable72
			}, {
				name = "Position Surprise Strike from Stealth",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {3,5.7,8.5,11.2,14,16.7,19.5,22.2,25},
				cost = CostTable36
			}, {
				name = "Ready and Able Cooldown",
				type = Type.Minor, 
				modType = Modifier.Cooldown,
				mod = {10,83,157,231,305,378,452,526,600},
				cost = CostTable36 -- TODO : CHECK (32 on L.I.P.S website, should be 36 though, need to check T6 to make sure)
			}, {
				name = "Small Snag Cooldown",
				type = Type.Major,
				modType = Modifier.Cooldown,
				mod = {1,6,12,17,23,28,34,39,45},
				cost = CostTable27
			}, {
				name = "Subtle Stab Critical Multiplier",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {3,5.7,8.5,11.2,14,16.7,19.5,22.2,25},
				cost = CostTable36
			}, {
				name = "Surprise Strike Critical Rating",
				type = Type.Major,
				modType = Modifier.Number,
				mod = ModifierTableRating(207,19),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable36
			}, {
				name = "Subtle Stab Damage Multiplier",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.1,3.2,4.3,5.5,6.6,7.7,8.8,10},
				cost = CostTable32
			}, {
				name = "Well Placed Strike Cooldown",
				type = Type.Minor, 
				modType = Modifier.Cooldown,
				mod = {4,11,18,25,32,39,46,53,60},
				cost = CostTable18
			}, {
				name = "Trick Range",
				type = Type.Minor,
				modType = Modifier.Number,
				mod = {3,3.4,3.8,4.2,4.7,5.1,5.5,5.9,6.3},
				cost = CostTable36
			}
		}
	},
	{
		name = "Tools",
		defaultLegacy = {
			name = "Incoming Healing Rating",
			type = Type.IncomingHealingRating,
			modType = Modifier.Rating,
			mod = ModifierTableIncomingHealingRating,
			cost = CostTableDefault,
			adjust = Adjust.IncomingHealingRating
		},
		legacies = 
		{
			{
				name = "Addle Induction Multiplier",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,7,13,19,26,32,38,44,50},
				cost = CostTable18
			}, {
				name = "Clever Retort Damage and Healing",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {4.5,8.5,13,17.5,22,26.5,31,35.5,40},
				cost = CostTable27
			}, {
				name = "Addle Cooldown",
				type = Type.Major,
				modType = Modifier.Cooldown,
				mod = {1,2,3,4,5,6,7,8,10},
				cost = CostTable27
			}, {
				name = "Confound Countdown Duration",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {1,2,3,4,5,6,7,8,10},
				cost = CostTable32
			}, {
				name = "Aim Cooldown",
				type = Type.Major,
				modType = Modifier.Cooldown,
				mod = {1,2,3,4,5,6,7,8,10},
				cost = CostTable18
			}, {
				name = "Gamble Chance",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {5,7,9,11,13,14,16,18,20},
				cost = CostTable27
			}, {
				name = "Hide in Plain Sight Cooldown",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {7,29,50,72,93,115,136,158,180},
				cost = CostTable36
			}, {
				name = "Healing - Mischievous Glee",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {5,10.6,16.2,21.8,27.5,33.1,38.7,44.3,50},
				cost = CostTable36
			}, {
				name = "Off-hand Critical Chance",
				type = Type.Major,
				modType = Modifier.Rating,
				mod = ModifierTableRating(207,19), 
				adjust = Adjust.LevelRangeAge,
				cost = CostTable32,
			}, {
				name = "Increased Range for Reveal Weakness",
				type = Type.Minor,
				modType = Modifier.Number,
				mod = {1,3,5,8,10,12,15,17,20}, 
				cost = CostTable18
			}, {
				name = "Devastating Critical Buff Duration",
				type = Type.Major,
				modType = Modifier.Duration,
				mod = {3,6,9,13,16,19,23,26,30},
				cost = CostTable27
			}, {
				name = "Stealth Level",
				type = Type.Minor,
				modType = Modifier.Number,
				mod = {1,2,3},
				cost = {
					{ 0, 142 },
					{ 0, 122 }, -- 95 @ 65 3rd, 81 @ 60 1st
					{ 0, 102 }, -- 68 @ 65 2nd age (-11?)
					{ 0, 81 },
					{ 0, 61 },
					{ 0, 41 }
				},
				adjustCost = CostTableAdjustStealth
			}, {
				name = "Tricks Duration",
				type = Type.Major,
				modType = Modifier.Duration,
				mod = {1,2,4,6,8,9,11,13,15},
				cost = CostTable23
			}, {
				name = "Sneak Movement Speed",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,2,3,4,6,7,8,9,10},
				cost = CostTable27
			}, {
				name = "Pulse Modifier for Glee",
				type = Type.Minor,
				modType = Modifier.Number,
				mod = {1,2,3,4,5},
				cost = {
					{0,81,156,189},
					{0,61,117,142},
					{0,51,98,119}, -- 17 @ lvl 65 3rd age
					{0,41,78,95},
					{0,31,59,71},
					{0,21,39,48}
				},
				adjustCost = CostTableAdjust189
			}, {
				name = "Skills Critical Multiplier",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.7,4.5,6.2,8,9.7,11.5,13.2,15},
				cost = CostTable36
			}, {
				name = "Positional Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.7,4.5,6.2,8,9.7,11.5,13.2,15},
				cost = CostTable36
			}
		}
	}
}

LegaciesWarden = 
{
	{
		name = "Melee weapon",
		defaultLegacy = {
			name = "DPS",
			type = Type.DPS,
			modType = Modifier.DPS,
			mod = ModifierTableDPS1H,
			adjust = Adjust.LevelPerAge,
			cost = CostTableDefault,
		}, 
		legacies = 
		{
			{
				name = "Ambush Critical Multiplier",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {3,5.7,8.5,11.2,14,16.7,19.5,22.2,25},
				cost = CostTable27
			}, {
				name = "Boar's Rush Critical Rating",
				type = Type.Minor,
				modType = Modifier.Rating,
				mod = ModifierTableRating(207,19),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable27
			}, {
				name = "War Cry Threat Up Rating",
				type = Type.Major,
				modType = Modifier.Rating,
				mod = ModifierTableRating(1,1),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable23
			}, {
				name = "Critical Strike Critical Multiplier",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {3,5.7,8.5,11.2,14,16.7,19.5,22.2,25},
				cost = CostTable27
			}, {
				name = "Wall of Steel Parry Rating",
				type = Type.Major,
				modType = Modifier.Rating,
				mod = ModifierTableRating(207,19),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable27
			}, {
				name = "Exhultation of Battle Threat Up Rating",
				type = Type.Major,
				modType = Modifier.Rating,
				mod = ModifierTableRating(1,1),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable36,
			}, {
				name = "Wages of Fear Positional Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.1,3.2,4.3,5.5,6.5,7.7,8.8,10},
				cost = CostTable27
			}, {
				name = "Hampering Javelin Duration",
				type = Type.Minor,
				modType = Modifier.Duration,
				mod = {1,2,4,6,8,9,11,13,15},
				cost = CostTable36
			}, {
				name = "Surety of Death Damage Over Time",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,2.1,3.2,4.3,5.5,6.6,7.7,8.8,10},
				cost = CostTable27
			}, {
				name = "Javelin Skills Max Range",
				type = Type.Minor,
				modType = Modifier.Number,
				mod = {1,2,3,4,5,6,7,8,9,10,11,12,13}, -- TODO check
				adjust = Adjust.LevelRange2Age,-- TODO check
				cost = CostTable72
			}, {
				name = "Spear of Virtue Threat Up Rating",
				type = Type.Major,
				modType = Modifier.Rating,
				mod = ModifierTableRating(1,1),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable23
			}, {
				name = "Spear of Virtue Damage",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,2.1,3.2,4.3,5.5,6.6,7.7,8.8,10},
				cost = CostTable27
			}, {
				name = "Mighty Blow Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.1,3.2,4.3,5.5,6.6,7.7,8.8,10},
				cost = CostTable27
			}, {
				name = "Onslaught Damage",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,2.1,3.2,4.3,5.5,6.6,7.7,8.8,10},
				cost = CostTable27
			}, {
				name = "Piercing Strike Threat Up Rating",
				type = Type.Major,
				modType = Modifier.Rating,
				mod = ModifierTableRating(1,1),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable23
			}, {
				name = "Power, Power Attack Gambit Line",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {-1,-2,-3,-4,-6,-7,-8,-9,-10},
				cost = CostTable18
			}, {
				name = "Recklessnes Attack Duration",
				type  = Type.Major,
				modType = Modifier.Percent,
				mod = {-1,-2,-3,-4,-6,-7,-8,-9,-10},
				cost = CostTable23
			}, {
				name = "Power, Fierce Resolve Gambit Line",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {-1,-2,-3,-4,-6,-7,-8,-9,-10},
				cost = CostTable32
			}
		}
	}, {
		name = "Javelin",
		defaultLegacy = {
			name = "DPS",
			type = Type.DPS,
			modType = Modifier.DPS,
			mod = ModifierTableDPS2H,
			adjust = Adjust.LevelPerAge,
			cost = CostTableDefault,
		},
		legacies = 
		{
			{
				name = "Dance of War Evade Rating",
				type = Type.Major,
				modType = Modifier.Rating,
				mod = ModifierTableRating(207,19),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable27
			}, {
				name = "Ambush and Careful Step Duration",
				type = Type.Minor,
				modType = Modifier.Duration,
				mod = {-0.3,-0.6,-1,-1.3,-1.7,-2,-2.3,-2.7,-3},
				cost = CostTable36
			}, {
				name = "Celebration of Skill Healing",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,3,5,6,8,10,12,13,15},
				cost = CostTable23
			}, {
				name = "Conservation in Combat Power Regeneration",
				type = Type.Major,
				modType = Modifier.Number,
				mod = {31,36.7,42.5,48.4,54.2,59.9,65.8,71.6,77.4,83.2,89,94.8,100.6,106.4 },
				adjust = Adjust.LevelRangeAge,
				cost = CostTable36
			}, {
				name = "Adroit Maneuver Duration",
				type = Type.Minor,
				modType = Modifier.Duration,
				mod = {1,2,3,4,5,6,7,8,10},
				cost = CostTable32
			}, {
				name = "Careful Step Duration",
				type = Type.Minor,
				modType = Modifier.Duration,
				mod = {3,6,9,13,16,19,23,26,30},
				cost = CostTable36
			}, {
				name = "Resolution Resist Rating",
				type = Type.Minor,
				modType = Modifier.Rating,
				mod = ModifierTableRating(207,19),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable27
			}, {
				name = "Determination In Combat Morale Regeneration",
				type = Type.Major,
				modType = Modifier.Number,
				mod = {65.3, 77.6, 89.8,102.1,114.3,126.5,138.8,151.1,163.3,175.6,187.8,200.1,212.3,224.5},
				adjust = Adjust.LevelRangeAge,
				cost = CostTable36
			}, {
				name = "Javelin Skills To-Hit Movement Penalty",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {-2,-3,-4,-5,-6,-7,-8,-9,-10},
				cost = CostTable27
			}, {
				name = "Forced March Max Power Penalty",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,2,3,4,5,6,7,8,9},
				cost = CostTable23
			}, {
				name = "Dark Before Dawn Power Restored",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {9,10,11,12,13,14,15,16,17,18,19,20,21,22},
				adjust = Adjust.LevelRangeAge,
				cost = CostTable36
			}, {
				name = "Power, Safeguard Gambit Line",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {-1,-2,-3,-4,-6,-7,-8,-8,-10},
				cost = CostTable32
			}, {
				name = "Restoration Morale Healed",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,3,5,6,8,10,12,13,15},
				cost = CostTable23
			}, {
				name = "Shield Mastery Block Rating",
				type = Type.Minor,
				modType = Modifier.Rating,
				mod = ModifierTableRating(207,19),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable27
			}, {
				name = "Safeguard Healing",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,3,5,6,8,10,12,13,15},
				cost = CostTable27
			}, {
				name = "Warden's Triumph Duration",
				type = Type.Minor,
				modType = Modifier.Duration,
				mod = {1,2.1,3.3,4.4,5.5,6.6,7.8,8.9,10},
				cost = CostTable36
			}, {
				name = "Heal Bonus for Conviction",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,3,5,6,8,10,12,13,15},
				cost = CostTable27
			}, {
				name = "Shield Piercer Duration",
				type = Type.Minor,
				modType = Modifier.Duration,
				mod = {1,2,4,6,8,9,11,13,15},
				cost = CostTable32
			}
		}
	}
}

LegaciesLoremaster = 
{
	{
		name = "Staff",
		defaultLegacy = {
			name = "Tactical Damage Rating",
			type = Type.TacticalDamageRating,
			modType = Modifier.Rating,
			mod = ModifierTableDefaultRating,
			adjust = Adjust.LevelAge,
			cost = CostTableDefault,
		}, 
		legacies = 	{
			{
				name = "Burning Ember Initial Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.8,4.5,6.2,8,9.7,11.5,13.2,15},
				cost = CostTable36
			}, {
				name = "Cracked Earth Range",
				type = Type.Major,
				modType = Modifier.Number,
				mod = {1,2,3,4,5,6,7,8,9,10,11,12,13}, -- TODO CHECK (checked lvl 51 3rd age 1..9), lvl 65 2nd age + 4 {1,0,0,0,4...
				adjust = Adjust.LevelRange2Age, -- TODO CHECK
				cost = CostTable54
			}, {
				name = "Burning Embers Range",
				type = Type.Minor,
				modType = Modifier.Number,
				mod = {1,2,3,4,5,6,7,8,9,10,11,12,13}, -- TODO CHECK +3 @ lvl 59 2nd age {0,0,0,3}
				adjust = Adjust.LevelRange2Age, -- TODO CHECK
				cost = CostTable54
			}, {
				name = "Ents Go To War Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.1,3.2,4.3,5.5,6.6,7.7,8.8,10},
				cost = CostTable32
			}, {
				name = "Cracked Earth Damage",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,2.7,4.5,6.2,8,9.7,11.5,13.2,15},
				cost = CostTable32
			}, {
				name = "Fire Skills Critical Multiplier",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {3,5.7,9.5,11.2,14,16.7,19.5,22.2,25},
				cost = CostTable32
			}, {
				name = "Lightning Skills Critical Rating",
				type = Type.Minor,
				modType = Modifier.Rating,
				mod = ModifierTableRating(207,19),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable32
			}, {
				name = "Gust of Wind Damage",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,2.7,4.5,6.2,8,9.7,11.5,13.2,15},
				cost = CostTable32
			}, {
				name = "Light of the Rising Dawn Critical Multiplier",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.7,4.5,6.2,8,9.7,11.5,13.2,15},
				cost = CostTable32
			}, {
				name = "Lightning Storm Damage",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,2.1,3.2,4.3,5.5,6.6,7.7,8.8,10},
				cost = CostTable36
			}, {
				name = "Light of the Rising Dawn Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.7,4.5,6.2,8,9.7,11.5,13.2,15},
				cost = CostTable36
			}, {
				name = "Share the Power Increase",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2,3,4,6,7,8,9,10},
				cost = CostTable23
			}, {
				name = "Tactical Skills Direct Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.1,3.2,4.3,5.5,6.6,7.7,8.8,10},
				cost = CostTable36
			}, {
				name = "Sticky Gourd Direct Damage",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,2.1,3.2,4.3,5.5,6.6,7.7,8.8,10},
				cost = CostTable32
			}, {
				name = "Staff Strike Cooldown",
				type = Type.Major,
				modType = Modifier.Cooldown,
				mod = {1,1.5,2,2.5,3,3.5,4,4.5,5},
				cost = CostTable18
			}, {
				name = "Test of Will Damage",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,2.7,4.5,6.2,8,9.7,11.5,13.2,15},
				cost = CostTable36
			}, {
				name = "Storm Lore Damage",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,2.7,4.5,6.2,8,9.7,11.5,13.2,15},
				cost = CostTable32
			}
		}
	},
	{
		name = "Book",
		defaultLegacy = {
			name = "Tactical Healing Rating",
			type = Type.TacticalHealingRating,
			modType = Modifier.Rating,
			mod = ModifierTableDefaultRating,
			adjust = Adjust.LevelAge,
			cost = CostTableDefault
		},
		legacies =
		{
			{
				name = "Ancient Craft Targets",
				type = Type.Minor,
				modType = Modifier.Number,
				mod = {1,2,3,4,5},
				cost = {
					{0,166,308,378},
					{0,142,264,324}, -- 41 @ 65 2nd age
					{0,119,220,270},
					{0,95,176,216},
					{0,71,132,162},
					{0,48,88,108} -- 18 @ lvl 60 2nd age
				},
				adjustCost = CostTableAdjust378
			}, {
				name = "Bane Flare Target",
				type = Type.Minor,
				modType = Modifier.Number,
				mod = {1,2,3,4,5},
				cost = { 
					{0,166,308,378},
					{0,142,264,324},
					{0,119,220,270},
					{0,95,176,216}, -- 27 @ 65 2nd age
					{0,71,132,162},
					{0,48,88,108}
				},
				adjustCost = CostTableAdjust378
			}, {
				name = "Burning Embers Pulses",
				type = Type.Major,
				modType = Modifier.Number,
				mod = {1,2,3,4,5},
				cost = {
					{0,71,137,166}, -- TODO CHECK
					{0,61,117,142}, -- 34 @ lvl 56 3rd
					{0,51,98,118},	-- 29 @ 55 3rd age, 17@65 3rd age, 23 @ 58 3rd age
					{0,41,78,95}, -- 27 @ 53 3rd
					{0,31,59,71},
					{0,21,39,48}
				},
				adjustCost = CostTableAdjust166
			}, {
				name = "Cure Resistance Duration",
				type = Type.Minor,
				modType = Modifier.Duration,
				mod = {5,11,18,25,32,39,46,53,60},
				cost = CostTable18
			}, {
				name = "Wizard Fire Pulses",
				type = Type.Major,
				modType = Modifier.Number,
				mod = {1,2,3,4,5},
				cost = {
					{0,71,137,166}, -- 40 @ 57 3rd
					{0,61,117,142}, -- 21 @ 65 3rd
					{0,51,98,118}, -- 34 @ 52 3rd
					{0,41,78,95}, -- 9 @ 65 2nd age, 23 @ 55 3rd, 14 @ 65 3rd
					{0,31,59,71}, -- 14 @ 58 3rd, 7 @ 65 2nd (app)
					{0,21,39,48} -- 7 @ 60 2nd age
				},
				adjustCost = CostTableAdjust166
			}, {
				name = "Fire Damage Over Time",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,2.7,4.5,6.2,8,9.7,11.5,13.2,15},
				cost = CostTable36
			}, {
				name = "Threat - Sign of the Wild Rage",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,3,5,6,8,10,12,13,15},
				cost = CostTable23
			}, {
				name = "Test of Will Devastate Damage",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,2.7,4.5,6.2,8,9.7,11.5,13.2,15},
				cost = CostTable27
			}, {
				name = "Fire Skills Critical Rating",
				type = Type.Major,
				modType = Modifier.Rating,
				mod = ModifierTableRating(207,19),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable32
			}, {
				name = "Target Resistance (Fire Skills)",
				type = Type.Major,
				modType = Modifier.Resist,
				mod = ModifierTableRating(-460,-50),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable32
			}, {
				name = "Fire-lore Targets",
				type = Type.Minor,
				modType = Modifier.Number,
				mod = {1,2,3,4,5},
				cost = {
					{0,166,308,378},
					{0,142,264,324},
					{0,119,220,270},
					{0,95,176,216},
					{0,71,132,162},
					{0,48,88,108}
				},
				adjustCost = CostTableAdjust378
			}, {
				name = "Healing from Beacon of Hope",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,3,5,6,8,10,12,13,15},
				cost = CostTable23
			}, {
				name = "Target Resistance (Debuffing Skills)",
				type = Type.Major,
				modType = Modifier.Rating,
				mod = ModifierTableRating(-1105,-105),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable23
			}, {
				name = "Signs of Power Durations",
				type = Type.Major,
				modType = Modifier.Duration,
				mod = {3,6,9,13,16,19,23,25,30},
				cost = CostTable18
			}, {
				name = "Target Resistance (Damaging Skills)",
				type = Type.Major,
				modType = Modifier.Rating,
				mod = ModifierTableRating(-460,-50),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable32
			}, {
				name = "Inner Flame Healing",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,7,13,19,26,32,38,44,50},
				cost = CostTable23
			}, {
				name = "Morale - Sign of the Wild Protection",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = { 1,2,3,4,5,6 },
				cost = {
					{9,27,39,54,72},
					{8,22,32,44,59},
					{7,19,27,38,50},
					{6,16,22,31,41},
					{4,12,18,24,32},
					{3,9,13,17,23}
				},
				-- adjustCost = CostTableAdjust72 TODO: probably does not adjust, need to make sure
			}
		}
	}
}

LegaciesChampion = 
{
	{
		name = "Weapon (One Handed)",
		defaultLegacy = {
			name = "DPS",
			type = Type.DPS,
			modType = Modifier.DPS,
			mod = ModifierTableDPS1H,
			adjust = Adjust.LevelPerAge,
			cost = CostTableDefault
		}, 
		legacies = 
		{
			{
				name = "Area of Effect Skill Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.1,3.2,4.3,5.5,6.6,7.7,8.8,10},
				cost = CostTable36
			}, {
				name = "Combat-only Effect Removal Delay",
				type = Type.Minor,
				modType = Modifier.Duration,
				mod = {1,1.5,2,2.5,3,3.5,4,4.5,5},
				cost = CostTable32
			}, {
				name = "Brutal Strikes Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.7,4.5,6.2,8,9.7,11.5,13.2,15},
				cost = CostTable23
			}, {
				name = "Critical Damage Multiplier",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {5,11,16,22,28,33,39,44,50},
				cost = CostTable32
			}, {
				name = "Damage for Feral/Savage Strikes",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.7,4.5,6.2,8,9.7,11.5,13.2,15},
				cost = CostTable23
			}, {
				name = "Damage for Relentless/Remorless Strikes",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.7,4.5,6.2,8,9.7,11.5,13.2,15},
				cost = CostTable23
			}, {
				name = "Wild Attack Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.7,4.5,6.2,8,9.7,11.5,13.2,15},
				cost = CostTable23
			}, {
				name = "Fear Nothing Cooldown",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {5,15,26,36,47,58,68,79,90},
				cost = CostTable27
			}, {
				name = "Harmstring Duration",
				type = Type.Minor,
				modType = Modifier.Duration,
				mod = {1,2,3,4,6,7,8,9,10},
				cost = CostTable32
			}, {
				name = "Ferocious Strikes Cooldown",
				type = Type.Major,
				modType = Modifier.Cooldown,
				mod = {1,2,4,6,8,9,11,13,15},
				cost = CostTable32
			}, {
				name = "Horn Damage",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,2.1,3.2,4.3,5.5,6.6,7.7,8.8,10},
				cost = CostTable23
			}, {
				name = "Increased Rend Armour Reduction",
				type = Type.Minor,
				modType = Modifier.Rating,
				mod = {79,87,95,103,111,119,126,134,142,150,157,165,173,181}, -- TODO check first two values, and last (extrapolated)
				adjust = Adjust.LevelRangeAge,
				cost = CostTable27
			}, {
				name = "Reduced Cooldown for Battle Frenzy",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {1,3,5,8,10,12,15,17,20},
				cost = CostTable18
			}, {
				name = "Rend Bleed Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {3,5.7,8.5,11.2,14,16.7,19.5,22.2,25},
				cost = CostTable23
			}, {
				name = "Sudden Defence Duration",
				type = Type.Minor,
				modType = Modifier.Duration,
				mod = {3,6,10,13,17,20,23,27,30},
				cost = CostTable36
			}, {
				name = "Sprint Duration",
				type = Type.Minor,
				modType = Modifier.Duration,
				mod = {3,6,9,13,16,19,23,26,30},
				cost = CostTable27
			}
--[[			DEPRECATED LEGACY
			, { -- TODO 
				name = "Hedge wound resist rating",
				type = Type.Minor,
				modType = Modifier.Rating,
				mod = ModifierTableRating(207,19),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable? -- TODO 
			}--]]
		}
	},
	{
		name = "Weapon (Two Handed)",
		defaultLegacy = {
			name = "DPS",
			type = Type.DPS,
			modType = Modifier.DPS,
			mod = ModifierTableDPS2H,
			adjust = Adjust.LevelPerAge,
			cost = CostTableDefault,
		},
		legacies = {}	-- legacies set to same as one handed below 
	},
	{
		name = "Rune",
		defaultLegacy = {
			name = "Incoming Healing Rating",
			type = Type.IncomingHealingRating,
			modType = Modifier.Rating,
			mod = ModifierTableIncomingHealingRating,
			adjust = Adjust.IncomingHealingRating,
			cost = CostTableDefault
		},
		legacies =
		{
			{
				name = "Blade Line Area of Efect Power Cost",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {-1,-2,-3,-4,-6,-7,-8,-9,-10},
				cost = CostTable27
			}, {
				name = "Ardour/Glory Pip Interval",
				type = Type.Major,
				modType = Modifier.Number,
				mod = {-1,-2,-3,-4},
				cost = {
					{0,189,376},
					{0,162,322},
					{0,135,269}, -- 90 @ lvl 51 LI, 45 @ lvl 65 2nd age (app)
					{0,108,215},
					{0,81,161},
					{0,54,108}
				},
				adjustCost = CostTableAdjust376
			}, {
				name = "Ardour/glory in-Combat Power Regen",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,3,5,6,8,10,12,13,15},
				cost = CostTable23
			}, {
				name = "Adamant/Invincible Duration",
				type = Type.Minor,
				modType = Modifier.Duration,
				mod = {3,6,10,13,17,20,23,27,30},
				cost = CostTable18
			}, {
				name = "Ardour/Glory Parry and Evade Rating",
				type = Type.Major,
				modType = Modifier.Rating,
				mod = ModifierTableRating(207,19),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable27
			}, {
				name = "Harmstring Range",
				type = Type.Minor,
				modType = Modifier.Number,
				mod = {0.5,1,2}, -- TODO: Checked: +2 at lvl 65 2nd age rank 2, +0.5 rank 1 lvl 59 third age, +0.5 rank 1 lvl 54 2nd age
				cost = {
					{0,142},
					{0,122},
					{0,102},
					{0,81},
					{0,61},
					{0,41}
				},
				-- adjust = Adjust.LevelRange2Age, -- TODO LevelRange2Age ? with {?, 0.5, 1, ?, 2, ?} ?
				adjustCost = CostTableAdjustHarmstringRange
			}, {
				name = "Heroics Morale Heal Chance",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,11,21,31,41,50,60,70,80},
				cost = CostTable18
			}, {
				name = "Bracing Attack Heal",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,3,5,6,8,10,12,13,15},
				cost = CostTable27
			}, {
				name = "Dire Need Skill Cooldown",
				type = Type.Major,
				modType = Modifier.Cooldown,
				mod = {10,83,157,231,305,378,452,526,600},
				cost = CostTable32
			}, {
				name = "Ebbing Ire Cooldown",
				type = Type.Major,
				modType = Modifier.Cooldown,
				mod = {4,11,18,25,32,39,46,53,60},
				cost = CostTable36
			}, {
				name = "Sudden Defence Parry and Evade Rating",
				type = Type.Minor,
				modType = Modifier.Rating,
				mod = ModifierTableRating(207,19),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable27
			}, {
				name = "Strikes Line Power Cost",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {-1,-2,-3,-4,-6,-7,-8,-9,-10},
				cost = CostTable27
			}, {
				name = "Swift Strike Power Cost",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {-2,-6,-9,-13,-16,-20,-23,-27,-30},
				cost = CostTable27
			}, {
				name = "Stun Duration - Champion's Horn",
				type = Type.Major,
				modType = Modifier.Duration,
				mod = {1,1.5,2,2.5,3,3.5,4,4.5,5},
				cost = CostTable36
			}, {
				name = "Fight On Duration",
				type = Type.Minor,
				modType = Modifier.Duration,
				mod = {3,6,9,13,16,19,23,26,30},
				cost = CostTable32
			}, {
				name = "Rend Pulses",
				type = Type.Minor,
				modType = Modifier.Number,
				mod = {1,2,3,4,5},
				cost = {
					{0,142,273,331},
					{0,122,234,284},
					{0,102,195,237},
					{0,81,156,189},  -- 36 @lvl 61 third age, 18 @ lvl 65 2nd age
					{0,61,117,142},
					{0,41,78,95}
				},
				adjustCost = CostTableAdjust331
			}, {
				name = "Rising Ire Cooldown",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {1,2,3,4,5,6,7,8,10},
				cost = CostTable36
			}
		}
	}
}
LegaciesChampion[2].legacies = LegaciesChampion[1].legacies;

LegaciesCaptain = 
{
	{
		name = "Weapon (two handed)",
		defaultLegacy = {
			name = "DPS",
			type = Type.DPS,
			modType = Modifier.DPS,
			mod = ModifierTableDPS2H,
			adjust = Adjust.LevelPerAge,
			cost = CostTableDefault,
		}, 
		legacies = 
		{
			{
				name = "Blade of Elendil Damage",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {3,5.7,8.5,11.2,14,16.7,19.5,22.2,25},
				cost = CostTable32
			}, {
				name = "Cry Power Cost",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {-1,-2,-3,-4,-6,-7,-8,-9,-10},
				cost = CostTable18
			}, {
				name = "Defensive Strike Armour Buff",
				type = Type.Minor,
				modType = Modifier.Rating,
				mod = ModifierTableRating( 50, 35 ),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable23
			}, {
				name = "Devastating Blow Critical Rating",
				type = Type.Major,
				modType = Modifier.Rating,
				mod = ModifierTableRating(207,19),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable23
			}, {
				name = "Cutting Attack Bleed Damage",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {4,8.5,13,17.5,22,26.5,31,35.5,40},
				cost = CostTable27
			}, {
				name = "Increased Duration of Make Haste",
				type = Type.Minor,
				modType = Modifier.Duration,
				mod = {1,4,7,10,13,16,19,22,25},
				cost = CostTable18
			}, {
				name = "Kick Cooldown",
				type = Type.Major,
				modType = Modifier.Cooldown,
				mod = {1,4,8,11,15,19,22,26,30},
				cost = CostTable27
			}, {
				name = "Pressing Attack Max Targets",
				type = Type.Major,
				modType = Modifier.Number,
				mod = {1,2,3,4,5},
				cost = {
					{0,142,264,324},
					{0,119,220,270}, -- 45 @ lvl 60 2nd age (app)
					{0,95,176,216}, -- 45 @ lvl 60 2rd, 36 @ lvl 65 3rd, 54 @ lvl 56 3rd
					{0,71,132,162}, -- 21 @ 65 2nd, 34@ 59 3rd, 34 @ 62 3rd
					{0,48,88,108}, -- 32@ lvl 52 3rd age
					{0,42,77,95}
				},
				adjustCost = CostTableAdjust324
			}, {
				name = "Melee Skill Power Cost",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {-1,-2,-3,-4,-6,-7,-8,-9,-10},
				cost = CostTable23
			}, {
				name = "Pressing Attack Critical Rating",
				type = Type.Major,
				modType = Modifier.Rating,
				mod = ModifierTableRating(207,19),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable23
			}, {
				name = "Routing Cry Damage",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {4,9.5,13,17.5,22,26.5,31,35.5,40},
				cost = CostTable27
			}, {
				name = "Tactics On Guard Parrry Rating Buff",
				type = Type.Minor, 
				modType = Modifier.Rating,
				mod = ModifierTableRating(207,19),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable36
			}, {
				name = "Tactics: Relentless Attack Critical Rating Buff",
				type = Type.Minor, 
				modType = Modifier.Rating,
				mod = ModifierTableRating(207,19),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable27
			}, {
				name = "Telling Mark Damage",
				type = Type.Major, 
				modType = Modifier.Percent,
				mod = {2,2.3,2.7,3.1,3.5,3.8,4.2,4.6,5},
				cost = CostTable36
			}, {
				name = "Morale from Motivating Speech",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,1.5,2,2.5,3,3.5,4,4.5,5},
				cost = CostTable36
			}, {
				name = "To Arms Duration",
				type = Type.Major, 
				modType = Modifier.Duration,
				mod = {1,2,4,6,8,9,11,13,15},
				cost = CostTable27
			}
		}
	},
	{
		name = "Weapon (One Handed)",
		defaultLegacy = {
			name = "DPS",
			type = Type.DPS,
			modType = Modifier.DPS,
			mod = ModifierTableDPS1H,
			adjust = Adjust.LevelPerAge,
			cost = CostTableDefault,
		},
		legacies = {}	-- legacies set to same as two handed below 
	},	
	{
		name = "Emblem",
		defaultLegacy = {
			name = "Tactical Healing Rating",
			type = Type.TacticalHealingRating,
			modType = Modifier.Rating,
			mod = ModifierTableDefaultRating,
			adjust = Adjust.LevelAge,
			cost = CostTableDefault
		},
		legacies =
		{
			{
				name = "Captain's Escape from Darkness Cooldown",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {10,83,157,231,305,378,452,526,600},
				cost = CostTable36
			}, {
				name = "Cooldown for Shield of the Dunedain",
				type = Type.Minor, 
				modType = Modifier.Cooldown,
				mod = {7,29,50,72,93,115,136,158,180},
				cost = CostTable36
			}, {
				name = "Duration of In Defence of Middle-Earth",
				type = Type.Minor,
				modType = Modifier.Duration,
				mod = {30,50,70,90,110,130,150,170,190},
				cost = CostTable18
			}, {
				name = "Grave Wound Cooldown",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {1,1.5,2,2.5,3,3.5,4,4.5,5},
				cost = CostTable18
			}, {
				name = "Healing from Rallying Cry",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,3,5,6,8,10,12,13,15},
				cost = CostTable23
			}, {
				name = "Healing from Strength of Will",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,3,5,6,8,10,12,13,15},
				cost = CostTable27
			}, {
				name = "Rallying Cry Cooldown",
				type = Type.Major,
				modType = Modifier.Cooldown,
				mod = {1,4,8,11,15,19,22,26,30},
				cost = CostTable32
			}, {
				name = "Melee Skills Healing",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,3,5,6,8,10,12,13,15},
				cost = CostTable27
			}, {
				name = "Reduced Cooldown for Muster Courage",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {1,4,8,11,15,19,22,26,30},
				cost = CostTable32
			}, {
				name = "Shadow's Lament Cooldown",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {1,2,4,6,8,9,11,13,15},
				cost = CostTable32
			}, {
				name = "Reduced Morale Cost for Time of Need",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,7,13,19,26,32,38,44,50},
				cost = CostTable23
			}, {
				name = "Valiant Strike Morale Return",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2,3,4,6,7,8,9,10},
				cost = CostTable27
			}, {
				name = "Tactics: Focus in-Combat Power Regen Buff",
				type = Type.Major,
				modType = Modifier.Number,
				mod = {30.6,36.6,42,48,54,59.4,65.4,71.4,77.4,82.8,88.8,94.8,100.2,106.2},
				adjust = Adjust.LevelRangeAge,
				cost = CostTable32
			}, {
				name = "Time of Need Cooldown",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {10,83,157,231,305,378,452,526,600},
				cost = CostTable23
			}, {
				name = "Vocal Skills Healing",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,3,5,6,8,10,12,13,15},
				cost = CostTable27
			}, {
				name = "Words of Courage Power and Morale Cost",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {-1,-2,-3,-4,-6,-7,-8,-9,-10},
				cost = CostTable36
			}
		}
	}
}

LegaciesCaptain[2].legacies = LegaciesCaptain[1].legacies;

LegaciesGuardian = 
{
	{
		name = "Weapon",
		defaultLegacy = {
			name = "DPS",
			type = Type.DPS,
			modType = Modifier.DPS,
			mod = ModifierTableDPS1H,
			adjust = Adjust.LevelPerAge,
			cost = CostTableDefault,
		}, 
		legacies = 
		{
			{
				name = "Charge Duration",
				type = Type.Minor,
				modType = Modifier.Duration,
				mod = {1,2,3,4,6,7,8,9,10},
				cost = CostTable18
			}, {
				name = "Guardian Area Effect Melee Targets",
				type = Type.Major,
				modType = Modifier.Number,
				mod = {1,2,3,4,5},
				cost = {
					{0,166,308,378},
					{0,142,264,324},
					{0,119,220,270}, -- 34 @ lvl 60 1st age
					{0,95,176,216},
					{0,71,132,162},
					{0,48,88,108} 
				},
				adjustCost = CostTableAdjust378
			}, { -- TODO : 1h only ?
				name = "Bash Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.1,3.2,4.3,5.5,6.6,7.7,8.8,10},
				cost = CostTable18
			}, { -- TODO: 2h only ?
				name = "Brutal Assault Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.1,3.2,4.3,5.5,6.6,7.7,8.8,10},
				cost = CostTable27
			}, {
				name = "Guardian Bleed Damage",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {2,4.2,6.5,8.7,11,13.2,15.5,17.7,20},
				cost = CostTable36
			}, {
				name = "Guardian Bleed Pulses",
				type = Type.Minor,
				modType = Modifier.Number,
				mod = {1,2,3,4,5},
				cost = {
					{0,142,273,331},
					{0,122,234,284},
					{0,102,195,237},
					{0,81,156,189}, -- 18 @ lvl 65 2nd age
					{0,61,117,142},
					{0,41,78,95}
				},
				adjustCost = CostTableAdjust331
			}, {
				name = "Overwhelm Critical Rating",
				type = Type.Major,
				modType = Modifier.Rating,
				mod = ModifierTableRating(884,84),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable32
			}, {
				name = "Stamp Cooldown",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {1,4,8,11,15,19,22,26,30},
				cost = CostTable27
			}, {
				name = "Sweeping Cut Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.1,3.2,4.3,5.5,6.6,7.7,8.8,10},
				cost = CostTable27
			}, {
				name = "Guardian's Ward Duration",
				type = Type.Major,
				modType = Modifier.Duration,
				mod = {1,2,3,4,5,6,7,8,10},
				cost = CostTable32
			}, {
				name = "Targeted Melee Skill Range",
				type = Type.Minor,
				modType = Modifier.Number,
				mod = {0.5,0.6,0.8,0.9,1.1,1.2,1.4,1.5,1.7,1.8,2.0,2.1,2.3,2.4}, -- TODO check first two values, last value (extrapolated)
				adjust = Adjust.LevelRangeAge, -- TODO: LevelRange2Age ?
				cost = CostTable36
			}, {
				name = "Guardian's Pledge Cooldown",
				type = Type.Major,
				modType = Modifier.Cooldown,
				mod = {4,11,18,25,32,39,46,53,60},
				cost = CostTable32
			}, {
				name = "Whirling Retaliation Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.1,3.2,4.3,5.5,6.6,7.7,8.8,10},
				cost = CostTable27
			}, { -- TODO 1H only ?
				name = "Vexing Blow Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.1,3.2,4.3,5.5,6.6,7.7,8.8,10},
				cost = CostTable18
			}, {
				name = "Turn the Tables Cooldown",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {5,15,26,36,47,58,68,79,90},
				cost = CostTable32
			}, {
				name = "Warrior's Heart Duration",
				type = Type.Minor,
				modType = Modifier.Duration,
				mod = {5,11,18,25,32,39,46,53,60},
				cost = CostTable27
			}, {
				name = "To the King Damage",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,2.1,3.2,4.3,5.5,6.6,7.7,8.8,10},
				cost = CostTable27
			}
		}
	},
	{
		name = "Weapon (Two Handed)",
		defaultLegacy = {
			name = "DPS",
			type = Type.DPS,
			modType = Modifier.DPS,
			mod = ModifierTableDPS2H,
			adjust = Adjust.LevelPerAge,
			cost = CostTableDefault,
		},
		legacies = {}	-- legacies set to same as one handed below 
	},	
	{
		name = "Belt",
		defaultLegacy = {
			name = "Shield Use Rank",
			type = Type.ShieldUse,
			modType = Modifier.Rating,
			mod = ModifierTableDefaultRating,
			adjust = Adjust.LevelAge,
			cost = CostTableDefault
		},
		legacies =
		{
			{
				name = "Catch a Breath Cooldown",
				type = Type.Major,
				modType = Modifier.Cooldown,
				mod = {1,4,8,11,15,19,22,26,30},
				cost = CostTable27
			}, {
				name = "Catch a Breath Morale Heal",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = { 1,3,5,6,8,10,12,13,15},
				cost = CostTable27
			}, {
				name = "Cry Resist Chance",
				type = Type.Major,
				modType = Modifier.Rating, 
				mod = ModifierTableRating( 207, 19 ),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable32
			}, {
				name = "Challenge Targets",
				type = Type.Major,
				modType = Modifier.Number,
				mod = {1,2,3,4,5},
				cost = {
					{0,119,220,270},
					{0,95,176,216}, --63, 95 lvl 53 third age (-9 / level range & age ?), 54 @ 55 third age
					{0,71,132,162}, -- 48 @ 52 3rd age (+0),  48 @ 53 third age, 41 @ 56 3rd age(+1), 34 @ 59 3rd age (+2) (-7 / Level range & age ?), 
					{0,48,88,108}, -- 23 @ 60 3rd age(ie, +2 LI) , 27 @ 55 3rd age
					{0,42,77,95}, -- 16, @ 60 2nd age, (ie, +3 LI)  -  16 @ 65 3rd age (ie + 3 LI) (-4 / level range & age ?), 12 @ 65 2nd age
					{0,36,66,81}
				},
				adjustCost = CostTableAdjust270
			}, {
				name = "Guardian's Threat Parry and Block Rating",
				type = Type.Minor,
				modType = Modifier.Rating,
				mod = ModifierTableRating( 207, 19 ),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable32
			}, {
				name = "Guardian's Ward Block Rating",
				type = Type.Major,
				modType = Modifier.Rating,
				mod = ModifierTableRating( 207, 19 ),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable32
			}, {
				name = "Guardian's Ward Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.1,3.2,4.3,5.5,6.6,7.7,8.8,10},
				cost = CostTable18
			}, {
				name = "Power Restore on Reactions",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {50,88,125,163,200,238,275,313,350},
				cost = CostTable27
			}, {
				name = "Guardian's Ward Parry Rating",
				type = Type.Major,
				modType = Modifier.Rating,
				mod = ModifierTableRating( 207, 19 ),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable32
			}, {
				name = "Reactive Block Damage",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {300,625,750,975,1200,1425,1650,1875,2100},
				cost = CostTable18
			}, {
				name = "Increased Block, Parry and Evade from Protection",
				type = Type.Minor,
				modType = Modifier.Rating,
				mod = {122,132,141,151,160,170,179,189,198}, --TODO check adjust ? correct value for lvl 61 third age
				cost = CostTable32
			}, {
				name = "Shield Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {2,4,7,10,13,16,19,22,25},
				cost = CostTable63
			}, {
				name = "Shield Wall Range",
				type = Type.Minor,
				modType = Modifier.Number,
				 -- TODO check,,( checked +12 rank 9 2nd age 65, +8 at rank5 lvl 60 first age), need to check 0.5, +4 lvl 65 2nd age
				mod = {1,2,3,4,5,6,7,8,9,10,11,12,13},
				adjust = Adjust.LevelRange2Age, -- TODO CHECK
				cost = CostTable36
			}, {
				name = "Shield Smash Damage",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {2,4,7,10,13,16,19,22,25},
				cost = CostTable32
			}, {
				name = "Stagger Critical Rating",
				type = Type.Minor,
				modType = Modifier.Rating,
				mod = ModifierTableRating( 1105,105 ),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable32
			}, {
				name = "Threat Generation Up Rating",
				type = Type.Major,
				modType = Modifier.Rating,
				mod = ModifierTableRating(1,1),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable36
			}, {
				name = "Stagger Effect Duration",
				type = Type.Minor,
				modType = Modifier.Duration,
				mod = {1,2,3,4,5,6,7,8,10},
				cost = CostTable27
			}, {
				name = "Warrior's Heart Morale Heal",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {2,4,7,10,13,16,19,22,25},
				cost = CostTable23
			}, {
				name = "Stagger Positional Damage",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,2.7,4.6,6.2,8,9.7,11.5,13.2,15},
				cost = CostTable27
			}, { 
				-- TODO: keep checking
				-- Sting damage legacy behaves unlike any other legacy
				-- modifiers are shifted for level & age
				-- at +2 shift and beyond, though, the number of ranks decreases
				-- cost per rank computed as normal
				-- At a guess, this is unintended by Turbine, an accidental 10th value was probably inserted accidentally, causing this behaviour
				name = "Sting Damage", 
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.1,3.2,4.3,5.5,6.6,7.7,8.8,10,11.1},
				adjust = Adjust.StingDamage,
				-- 1...10 on a lvl 53 third age 9 ranks
				-- 2.1 .... 11.1 on a lvl 55 third age, 9 ranks
				-- 4.3 ... 11.1 on a lvl 65 third age, 7 ranks
				-- 11.1% on a lvl 59 first age @ rank 6
				-- ... 11.1 on a lvl 60 first age, 6 ranks
				-- 10% sting damage lvl 60 first age (huh ?)

				cost = {Cost54, Cost45, Cost36, Cost27, Cost23, Cost18 } -- Might be wrong, bit of extrapolation here
			}
		}
	}
}
LegaciesGuardian[2].legacies = LegaciesGuardian[1].legacies;

LegaciesHunter = 
{
	{
		name = "Ranged weapon",
		defaultLegacy = {
			name = "DPS",
			type = Type.DPS,
			modType = Modifier.DPS,
			mod = ModifierTableDPS2H,
			adjust = Adjust.LevelPerAge,
			cost = CostTableDefault,
		}, 
		legacies = 
		{
			{
				name = "Burn Hot Damage",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,2.1,3.2,4.3,5.5,6.6,7.7,8.8,10},
				cost = CostTable27
			}, {
				name = "Distracting Shot Resistance Penetration",
				type = Type.Minor,
				modType = Modifier.Rating,
				mod = ModifierTableRating( 460, 50 ),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable36
			}, {
				name = "Endurance Quick Shot Threat Down Rating",
				type = Type.Minor,
				modType = Modifier.Rating,
				mod = ModifierTableRating(1,1),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable27
			}, {
				name = "Distracting Shot Cooldown",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {1,2,4,6,8,9,11,13,15},
				cost = CostTable36
			}, {
				name = "Barbed Arrow Bleed Damage",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {6,11.5,17,22.5,28,33.5,39,44.5,50},
				cost = CostTable32
			}, {
				name = "Focus Bow Threat Down Rating",
				type = Type.Minor,
				modType = Modifier.Rating,
				mod = ModifierTableRating(1,1),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable32
			}, {
				name = "Induction Bow Power Cost",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {-1,-2,-3,-4,-6,-7,-8,-9,-10},
				cost = CostTable27
			}, {
				name = "Heart Seeker Damage",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {2,4.2,6.5,8.7,11,13.2,15.5,17.7,20},
				cost = CostTable36
			}, {
				name = "Induction Bow Critical Multiplier",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {3,5.7,8.5,11.2,14,16.7,19.5,22.2,25},
				cost = CostTable36
			}, {
				name = "Focus Bow Critical Multiplier",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {3,5.7,8.5,11.2,14,16.7,19.5,22.2,25},
				cost = CostTable36
			}, {
				name = "Focus Bow Power Cost",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {-1,-2,-3,-4,-6,-7,-8,-9,-10},
				cost = CostTable27
			}, {
				name = "Quick Shot Critical Rating",
				type = Type.Major,
				modType = Modifier.Rating,
				mod = {517,565,612,660,707,755,802,850,897,945,992,1040,1087,1135}, -- TODO Double check last three values
				adjust = Adjust.LevelRangeAge,
				cost = CostTable27
			}, {
				name = "Ranged Skill Evade Chance Modifier",
				type = Type.Major,
				modType = Modifier.Rating,
				mod = ModifierTableRating( -207,-19), 
				adjust = Adjust.LevelRangeAge,
				cost = CostTable32
			}, {
				name = "Ranged Evade Rating",
				type = Type.Minor,
				modType = Modifier.Rating,
				mod = ModifierTableRating( 207,19), 
				adjust = Adjust.LevelRangeAge,
				cost = CostTable32
			}, {
				name = "Induction Bow Threat Down Rating",
				type = Type.Minor,
				modType = Modifier.Rating,
				mod = ModifierTableRating(1,1),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable32
			}, {
				name = "Ranged Skill Block Chance Modifier",
				type = Type.Major,
				modType = Modifier.Rating,
				mod = ModifierTableRating( 207,19),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable32
			}, {
				name = "Merciful Shot Cooldown",
				type = Type.Major,
				modType = Modifier.Cooldown,
				mod = {1,2,3,4,5,6,7,8,10},
				cost = CostTable32
			}, {
				name = "Strength Quick Shot Slow",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2,3,4,6,7,8,9,10},
				cost = CostTable32
			}
		}
	},
	{
		name = "One-handed Weapon",
		defaultLegacy = {
			name = "DPS",
			type = Type.DPS,
			modType = Modifier.DPS,
			mod = ModifierTableDPS1H,
			adjust = Adjust.LevelPerAge,
			cost = CostTableDefault
		},
		legacies =
		{
			{
				name = "Agile Rejoinder Heal Chance",
				type = Type.Minor;
				modType = Modifier.Percent,
				mod = {2,14,27,39,51,63,76,88,100},
				cost = CostTable23
			}, {
				name = "Blindside Critical Rating",
				type = Type.Major,
				modType = Modifier.Rating,
				mod = {517,565,612,660,707,755,802,850,897,945,992,1040,1087,1135}, -- TODO:  CHECK Last three values
				adjust = Adjust.LevelRangeAge,
				cost = CostTable23
			}, {
				name = "Desperate Flight Cooldown",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {10,83,157,231,305,378,452,526,600},
				cost = CostTable32
			}, {
				name = "Critical Magnitude in Precision Stance",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,3,4,5,7,8,10,11,13},
				cost = CostTable32
			}, {
				name = "Beneath Notice Cooldown",
				type = Type.Major,
				modType = Modifier.Cooldown,
				mod = {5,19,33,48,62,76,91,105,120},
				cost = CostTable18
			}, {
				name = "Find the Path Movement Speed",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2,3,4,5,6},
				cost = { -- TODO:
					{14,41,59,81,108},
					{9,27,39,54,72},
					{7,21,30,41,54}, -- 7 @ lvl 53 third age, 7 @ lvl 60 3rd age
					{5,14,20,27,36}, -- 5 @ lvl 65 third age
					{4,12,18,24,32}, -- checked rank3+ costs. R2:  4 on level 65 2nd age 
--					{0,9,13,17,23} -- L.I.P.S website
					{4,11,15,21,27}-- first age lvl 65 : 4, 11, 15, 21, 27
				},
				-- adjustCost = CostTableAdjust108 -- costs don't seem to adjust for this legacy
			}, {
				name = "Improved Strength of Earth Morale Regen",
				type = Type.Major,
				modType = Modifier.Rating,
				mod = {60,120,180,240,300,360,420,480,540,600,660,720,780,840},
				adjust = Adjust.LevelRangeAge,
				cost = CostTable18
			}, {
				name = "Maximum Targets for AoE Skills",
				type = Type.Major,
				modType = Modifier.Number,
				mod = {1,2,3,4,5},
				cost = {
					{0,119,220,270},
					{0,95,176,216},
					{0,71,132,162},
					{0,48,88,108}, -- 18 on lvl 65 third age
					{0,42,77,95},
					{0,36,66,81} -- 7 on lvl 65 first age, 11 @ vl 65 2nd age
				},
				adjustCost = CostTableAdjust270
			}, {
				name = "Low Cut Bleed Chance",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,7,13,19,26,32,38,44,50},
				cost = CostTable23 -- checked T6 lvl 65 3rd age
			}, {
				name = "Melee Critical Multiplier",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {3,5.7,8.5,11.2,14,16.7,19.5,22.2,25},
				cost = CostTable36
			}, {
				name = "Melee Critical Rating",
				type = Type.Minor,
				modType = Modifier.Rating,
				mod = ModifierTableRating( 207, 19 ),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable36
			}, {
				name = "Needful Haste Duration",
				type = Type.Major,
				modType = Modifier.Duration,
				mod = {1,2,4,6,8,9,11,13,15},
				cost = CostTable32
			}, {
				name = "Stealth Detection",
				type = Type.Minor,
				modType = Modifier.Number,
				mod = {1,2,3},
				cost = {
					{0,142},
					{0,122},
					{0,102},
					{0,81},
					{0,61}, -- R3 61 checked on lvl 57 3rd age. R2: 61 @ lvl 57 3rd age
					{0,41},	 			
				},
				adjustCost = CostTableAdjustStealth
			}, {
				name = "Power Restored by Deep Concentration",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {2,6,9,13,16,20,23,27,30},
				cost = CostTable27
			}, {
				name = "Swift Stroke Parry and Evade Rating",
				type = Type.Minor,
				modType = Modifier.Rating,
				mod = ModifierTableRating( 207, 19 ),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable18
			}, {
				name = "Press Onward Cooldown",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {5,15,26,36,47,58,68,79,90},
				cost = CostTable32
			}
		}
	}
}

LegaciesRunekeeper = 
{
	{
		name = "Rune-stone",
		defaultLegacy = {
			name = "Tactical Damage Rating",
			type = Type.TacticalDamageRating,
			modType = Modifier.Rating,
			mod = ModifierTableDefaultRating,
			adjust = Adjust.LevelAge,
			cost = CostTableDefault,
		}, 
		legacies = 
		{
			{	
				name = "Fire Skill Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.7,4.5,6.2,8,9.7,11.5,13.2,15},
				cost = CostTable36
			}, {
				name = "Battle Attuned Skill Power Cost",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {-1,-3,-5,-6,-8,-10,-12,-13,-15},
				cost = CostTable27
			}, {
				name = "Chill of Winter Debuff Duration",
				type = Type.Minor,
				modType = Modifier.Duration,
				mod = {1,2,3,4,5,6,7,8,10},
				cost = CostTable36
			}, {
				name = "Chill of Winter Damage",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,2.7,4.5,6.2,8,9.7,11.5,13.2,15},
				cost = CostTable36
			}, {
				name = "Distracting Flame Cooldown",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {1,4,8,11,15,19,22,26,30},
				cost = CostTable27
			}, {
				name = "Fury of Storm Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.7,4.5,6.2,8,9.7,11.5,13.2,15},
				cost = CostTable36
			}, {
				name = "Healing",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,1.5,2,2.5,3,3.5,4,5,6},
				cost = CostTable36
			}, {
				name = "Glorious Foreshadowing Duration",
				type = Type.Minor,
				modType = Modifier.Duration,
				mod = {3,6,9,13,16,19,23,26,30},
				cost = CostTable32
			}, {
				name = "Healing Over Time",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2,3,4,6,7,8,9,10},
				cost = CostTable36
			}, {
				name = "Healing Attuned Skill Power Cost",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {-1,-3,-5,-6,-8,-10,-12,-13,-15},
				cost = CostTable27
			}, {
				name = "Fury of Storm Critical Multiplier",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {2,5.5,9,12.5,16,19.5,23,26.5,30},
				cost = CostTable36
			}, {
				name = "Vivid Imagery Targets",
				type = Type.Minor,
				modType = Modifier.Number,
				mod = {1,2,3,4,5},
				cost = {
					{0,119,220,270},
					{0,95,176,216},
					{0,71,132,162},
					{0,48,88,108},
					{0,42,77,95}, -- 20 @ 54 2nd age, 28 on starter third age
					{0,36,66,81} -- 7 @ lvl 65 1st age (app)
				},
				adjustCost = CostTableAdjust270
			}, {
				name = "Wrath of Flame Damage Over Time",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.7,4.5,6.2,8,9.7,11.5,13.2,15},
				cost = CostTable36
			}, {
				name = "Steady Attuned Skill Power",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {-1,-3,-5,-6,-8,-10,-12,-13,-15},
				cost = CostTable23
			}, {
				name = "Penetrate Target Resist",
				type = Type.Minor,
				modType = Modifier.Resist,
				mod = ModifierTableRating(-414,-38),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable36
			}
		}
	},
	{
		name = "Rune-satchel",
		defaultLegacy = {
			name = "Tactical Healing Rating",
			type = Type.TacticalHealingRating,
			modType = Modifier.Rating,
			mod = ModifierTableDefaultRating,
			adjust = Adjust.LevelAge,
			cost = CostTableDefault
		},
		legacies =
		{
			{
				name = "Chilling Rhetoric Cooldown",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {1,2,3,4,5,6,7,8,10},
				cost = CostTable18
			}, {
				name = "Ceaseless Argument Power Cost",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {-1,-3,-5,-6,-8,-10,-12,-13,-15},
				cost = CostTable27
			}, {
				name = "Distracting Winds Cooldown",
				type = Type.Major,
				modType = Modifier.Cooldown,
				mod = {4,11,18,25,32,39,46,53,60},
				cost = CostTable32
			}, {
				name = "Do Not Fall This Day Cooldown",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {5,23,43,63,83,101,121,140,160},
				cost = CostTable36
			}, {
				name = "Epic for the Ages Healing",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,2,3,4,6,7,8,9,10},
				cost = CostTable36
			}, {
				name = "Essence of Flame Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {2,4.2,6.5,8.7,11,13.2,15.5,17.7,20},
				cost = CostTable36
			}, {
				name = "Mending Verse Healing",
				type = Type.Minor,
				modType = Modifier.Percent,
				mod = {1,2,3,4,6,7,8,9,10},
				cost = CostTable36
			}, {
				name = "Frozen Epilogue Cooldown",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {5,24,43,63,82,101,121,140,160},
				cost = CostTable32
			}, {
				name = "Pulses Prelude to Hope",
				type = Type.Major,
				modType = Modifier.Number,
				mod = {2,3,4,5,6,7,8,9,10},
				cost = CostTable36
			}, {
				name = "Scribe's Spark Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {2,4.2,6.5,8.7,11,13.2,15.5,17.7,20},
				cost = CostTable27
			}, {
				name = "Self Motivation Power Return",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2.8,4.5,6.3,8,9.8,11.5,13.3,15},
				cost = CostTable32
			}, {
				name = "Shocking Words Stun Chance",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,3,6,8,11,13,15,18,20},
				cost = CostTable18
			}, {
				name = "Writ of Fire Damage",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {2,4.2,6.5,8.7,11,13.2,15.5,17.7,20},
				cost = CostTable32
			}, {
				name = "Writ of Health Healing",
				type = Type.Major,
				modType = Modifier.Percent,
				mod = {1,2,3,4,6,7,8,9,10},
				cost = CostTable32
			}, {
				name = "Word of Exaltation Cooldown",
				type = Type.Minor,
				modType = Modifier.Cooldown,
				mod = {1,4,8,11,15,19,22,26,30},
				cost = CostTable27
			}, {
				name = "Target Shocking Touch Resist Rating",
				type = Type.Minor,
				modType = Modifier.Resist,
				mod = ModifierTableRating( -690, -75 ),
				adjust = Adjust.LevelRangeAge,
				cost = CostTable27
			}
		}
	}
}

-- Stat legacies 
ModifierTableStat = {5,7,8,10,11,13,14,16,17,19,20,22,24,26}; -- TODO check first two values
LegaciesStat = 
{
	{
		name = "Agility",
		type = Type.Stat,
		modType = Modifier.Number,
		mod = ModifierTableStat,
		adjust = Adjust.LevelRangeAge,
		cost = CostTable23
	}, {
		name = "Fate",
		type = Type.Stat,
		modType = Modifier.Number,
		mod = ModifierTableStat,
		adjust = Adjust.LevelRangeAge,
		cost = CostTable23
	}, {
		name = "Might",
		type = Type.Stat,
		modType = Modifier.Number,
		mod = ModifierTableStat,
		adjust = Adjust.LevelRangeAge,
		cost = CostTable23		
	}, {
		name = "Vitality",
		type = Type.Stat,
		modType = Modifier.Number,
		mod = ModifierTableStat,
		adjust = Adjust.LevelRangeAge,
		cost = CostTable23
	}, {
		name = "Will",
		type = Type.Stat,
		modType = Modifier.Number,
		mod = ModifierTableStat,
		adjust = Adjust.LevelRangeAge,
		cost = CostTable23
	}
}