-- LegendaryItem class, handles level, age, legacies etc.

LegendaryItem = class( Turbine.Object );
function LegendaryItem:Constructor( initData )
	Turbine.Object.Constructor( self );
	
	self.name = initData.name;
	self.levelToUse = 65;
	self.age = 3;
	self.level = 70;

	self.legacies = {}; -- list of legacies
	self.legacyLookup = {}; -- stores legacy/id associations
	self.legacyReverseLookup = {}; -- stores id/legacy associations
	
	self.Changed = Equendil.Utils.Event(); -- event called without parameters whenever a legendary item changes in any way
	
	-- helper function to create a new legacy
	local newLegacy = function( legacyData, id )
		local legacy = Equendil.LIP.Legacy( legacyData, self );
		legacy.CostChanged:Add( function() self.Changed() end );
		table.insert( self.legacies, 1, legacy );
		self.legacyLookup[legacy] = id;
		self.legacyReverseLookup[id] = legacy;
		return legacy;
	end

	-- use a counter for IDs
	local id = 1;
	
	-- add 'default' legacy (DPS, Tactical Healing/Damage Rating, Incoming Healing Rating, Shield Use)
	newLegacy( initData.defaultLegacy, id ):SetActive(true); -- default legacy is always active
	id = id + 1;
	
	-- add regular legacies
	for k, v in ipairs( initData.legacies ) do
		newLegacy( v, id );
		id = id +1;
	end

	-- add stat legacies
	id = 1000; -- we want to leave some room for future addition of legacies by Turbine
	for k, v in ipairs( Equendil.LIP.LegaciesStat ) do
		newLegacy( v, id );
		id = id + 1;
	end
	
	-- sort the legacies: default legacy > major legacies > minor legacies, alphabetically if of same type
	local t = { [Equendil.LIP.Type.Major] = 1, [Equendil.LIP.Type.Minor] = 2, [Equendil.LIP.Type.Stat] = 3 };
	local compare = function( legacy1, legacy2 ) -- comparison function for sorting
		-- Getting nil values sent by table.sort, so checking for those ..
		if legacy1 == nil then return true; end
		if legacy2 == nil then return false; end
		
		local type1 = legacy1:GetType();
		local type2 = legacy2:GetType();
		if type1 == type2 then
			return legacy1.name < legacy2.name;
		end

		if t[type1] == nil then return true end;
		if t[type2] == nil then return false end;
		return t[type1] < t[type2];
	end
	
	table.sort( self.legacies, compare ); 
end

-- straight forward accessors
function LegendaryItem:GetLegacies() return self.legacies; end
function LegendaryItem:GetLevel() return self.level; end
function LegendaryItem:GetLevelToUse() return self.levelToUse; end
function LegendaryItem:GetAge()	return self.age; end
function LegendaryItem:GetName() return self.name; end
function LegendaryItem:SetLevel( level ) self.level = level; self.Changed(); end
function LegendaryItem:SetName( name ) self.name = name; self.Changed(); end
function LegendaryItem:SetAge( age ) self.age = age; self.Changed(); end
function LegendaryItem:SetLevelToUse( level ) self.levelToUse = level; self.Changed(); end

-- computes total points available on a legendary item
function LegendaryItem:GetTotalPoints()
	-- legendary items get 10 points for each level from 2 to 10, 12 points from lvl 11 to 20, 14 points from level 21 to 30,  
	-- 8/10/12 points from 31 to 70 for a 3rd/2nd/1st age
	
	-- helper function to determine number of effective levels in a range
	function levelsinrange(x, x0, x1 ) 
		if x >= x0 then
			x = math.min( x, x1 );
			return ( x - x0 + 1 );
		end
		return 0;
	end
	
	local points = levelsinrange( self.level, 2, 10 ) * 10 +
					levelsinrange( self.level, 11, 20 ) * 12 +
					levelsinrange( self.level, 21, 30 ) * 14 +
					levelsinrange( self.level, 31, 70 ) * ( 8 + 2 * ( 3 - self.age ) );
	return points;
end

-- computes spent points on a legendary item
function LegendaryItem:GetSpentPoints()
	local total = 0;
	for k, legacy in pairs( self.legacies ) do
		if legacy:IsActive() then
			total = total + legacy:GetTotalCurrentCost();
		end
	end
	return total;
end

-- Serialization

function LegendaryItem:GetData()
	local data = {};
	
	data.name = self.name;
	data.level = self.level;
	data.levelToUse = self.levelToUse;
	data.age = self.age;
	data.legacies = {};
	
	for k, v in pairs(self.legacies) do
		local id = self.legacyLookup[v];
		data.legacies[id] = {};
		data.legacies[id].rank = v:GetRank();
		data.legacies[id].tier = v:GetTier();
		data.legacies[id].active = v:IsActive();
	end
	
	return data;
end

function LegendaryItem:SetData( data )
	self.name = data.name;
	self.level = data.level;
	self.levelToUse = data.levelToUse;
	self.age = data.age;
	
	-- TODO : disable callbacks temporarily while altering legacies
	for k, v in pairs( data.legacies ) do
		local legacy = self.legacyReverseLookup[k];
		legacy:SetRank( v.rank );
		legacy:SetTier( v.tier );
		legacy:SetActive( v.active );
	end
end